@@ -1,7 +1,7 @@
 
 #' Scaffold R wrappers for Python functions
 #'
-#' @param python_function Fully qualfied name of Python function or class
+#' @param python_function Fully qualified name of Python function or class
 #'   constructor (e.g. `tf$layers$average_pooling1d`)
 #' @param r_prefix Prefix to add to generated R function name
 #' @param r_function Name of R function to generate (defaults to name of Python
@@ -202,7 +202,7 @@ py_function_custom_scaffold <- function(
     cat(text, sep = "\n")
   }
 
-  wrapper_output <- utils::capture.output(
+  wrapper_output <- capture.output(
     {
       docs <- reticulate::py_function_docs(python_function)
       docs <- process_docs_fn(docs)
@@ -213,7 +213,8 @@ py_function_custom_scaffold <- function(
 
       # Write docstrings for each parameters
       for(i in 1:length(docs$parameters)) {
-        param_doc <- process_param_doc_fn(docs$sections[i], docs)
+        param_name <- names(docs$parameters)[i]
+        param_doc <- process_param_doc_fn(docs$parameters[[param_name]], docs)
         write_line(paste0("#' @param ", " ", names(docs$parameters)[i], " ", param_doc))
       }
 
